==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TextCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TextCellInfoDescription } from "./TextCellInfoDescription";
/**
 * @hidden
 */
var TextCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TextCellInfoDescriptionMetadata, _super);
    function TextCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextCellInfoDescriptionMetadata.b = function (a) {
        if (TextCellInfoDescriptionMetadata.a == null) {
            TextCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextCellInfoDescriptionMetadata.c(TextCellInfoDescriptionMetadata.a);
        }
        if (a.g(TextCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(TextCellInfoDescriptionMetadata.a);
    };
    TextCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("TextValue", "String");
    };
    TextCellInfoDescriptionMetadata.d = function (a) {
        TextCellInfoDescriptionMetadata.b(a);
        a.u("TextCellInfo", function () { return new TextCellInfoDescription(); });
        a.t("TextCellInfo", TextCellInfoDescriptionMetadata.a);
    };
    TextCellInfoDescriptionMetadata.$t = markType(TextCellInfoDescriptionMetadata, 'TextCellInfoDescriptionMetadata');
    TextCellInfoDescriptionMetadata.a = null;
    return TextCellInfoDescriptionMetadata;
}(Base));
export { TextCellInfoDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TextCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { TextCellInfoDescription } from "./TextCellInfoDescription";
/**
 * @hidden
 */
var TextCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TextCellInfoDescriptionMetadata, _super);
    function TextCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextCellInfoDescriptionMetadata.b = function (a) {
        if (TextCellInfoDescriptionMetadata.a == null) {
            TextCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextCellInfoDescriptionMetadata.c(TextCellInfoDescriptionMetadata.a);
        }
        if (a.j(TextCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(TextCellInfoDescriptionMetadata.a);
    };
    TextCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("TextValue", "String");
    };
    TextCellInfoDescriptionMetadata.d = function (a) {
        TextCellInfoDescriptionMetadata.b(a);
        a.aa("TextCellInfo", function () { return new TextCellInfoDescription(); });
        a.z("TextCellInfo", TextCellInfoDescriptionMetadata.a);
    };
    TextCellInfoDescriptionMetadata.$t = markType(TextCellInfoDescriptionMetadata, 'TextCellInfoDescriptionMetadata');
    TextCellInfoDescriptionMetadata.a = null;
    return TextCellInfoDescriptionMetadata;
}(Base));
export { TextCellInfoDescriptionMetadata };
